'use client'

import * as React from 'react'
import { Check, ChevronsUpDown } from 'lucide-react'

import { cn } from '@/lib/utils'
import { Button } from '@/components/ui/button'
import {
  Command,
  CommandEmpty,
  CommandGroup,
  CommandInput,
  CommandItem,
  CommandList,
} from '@/components/ui/command'
import { Popover, PopoverContent, PopoverTrigger } from '@/components/ui/popover'

type Option = {
  value: any
  label: string
}

type Props = {
  options: Option[]
  placeholder: string
}
export function Combobox(props: Props) {
  const { options, placeholder } = props

  const [open, setOpen] = React.useState(false)
  const [value, setValue] = React.useState<any>()

  console.log(options)
  console.log(open)

  return (
    <Popover open={open} onOpenChange={setOpen}>
      <PopoverTrigger asChild>
        <Button
          variant="outline"
          role="combobox"
          aria-expanded={open}
          className="w-[200px] justify-between"
        >
          {value ? options.find((o) => o.value === value)?.label : placeholder || 'Select Option'}
          <ChevronsUpDown className="opacity-50" />
        </Button>
      </PopoverTrigger>
      <PopoverContent className="w-[200px] p-0">
        <Command>
          <CommandInput placeholder={placeholder || 'Select Option'} className="h-9" />
          <CommandList className="z-50">
            <CommandEmpty>No Copies found.</CommandEmpty>
            <CommandGroup>
              {options.map((o) => (
                <CommandItem
                  key={o.value}
                  value={o.value}
                  onSelect={(currentValue: any) => {
                    setValue(currentValue === value ? undefined : currentValue)
                    setOpen(false)
                  }}
                >
                  {o.label}
                  <Check
                    className={cn('ml-auto', value === o.value ? 'opacity-100' : 'opacity-0')}
                  />
                </CommandItem>
              ))}
            </CommandGroup>
          </CommandList>
        </Command>
      </PopoverContent>
    </Popover>
  )
}
